import { select, csv, scaleLinear, extent,
        axisLeft, axisBottom, format } from 'd3';

const svg=select('svg');
const height=parseFloat(svg.attr('height'));
const width=parseFloat(svg.attr('width'));

/*
d.acceleration=+d.acceleration;
d.cylinders=+d.cylinders;
d.displacement=+d.displacement;
d.horsepower=+d.horsepower;
d.mpg=+d.mpg;
d.weight=+d.weight;
d.year=+d.year;
*/

const render = data => {
  const title = 'Car Charts';
  const xValue = d => d.horsepower;
  const xAxisLabel='horsepower';
  const yValue = d => d.weight;
  const yAxisLabel='weight';
  
  const circleRadius=10;
  
  
  const margin ={top: 50, left:100, bottom:70, right:40};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  //console.log(xScale.domain());
  //console.log(xScale.range());
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight])
  	.nice();
  //console.log(yScale.domain());
  //console.log(yScale.range());
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  //const yAxis = axisLeft(yScale);
  //yAxis(g.append('g'));
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(5);
  
  const yAxisG = g.append('g').call(yAxis);
  
 	yAxisG.selectAll('.domain')
  		.remove();
 
  yAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y', -70)
  	.attr('x', -innerHeight/2)
  	.attr('fill', 'black')
    .text(yAxisLabel)
  	.attr('transform', `rotate(-90)`)
  	.attr('text-anchor','middle');
  
  //console.log(typeof(format('.3s')(1000000)));
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain')
  	.remove();
  
  xAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y', 60)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
    .text(xAxisLabel);
  
  
  g.selectAll('circle').data(data)
  .enter().append('circle')
  	.attr('cy', d => yScale(yValue(d)))
  	.attr('cx', d => xScale(xValue(d)))
  	.attr('r', circleRadius);
  
  g.append('text')
  	.attr('class','title')
  	.attr('y', -2)
  	.text(title);
};

csv ('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data=>{
		data.forEach(d=> {
    d.acceleration=+d.acceleration;
    d.cylinders=+d.cylinders;
    d.displacement=+d.displacement;
    d.horsepower=+d.horsepower;
    d.mpg=+d.mpg;
    d.weight=+d.weight;
    d.year=+d.year;
  });
  console.log(data);
  render(data);
});

